@@ -1,4 +1,9 @@
 # -*- coding: utf-8 -*-
+u"""
+RTB transactions are initiated when an exchange or other supply source sends a bid request to a bidder.
+The bid request consists of a bid request object, at least one impression object,
+and may optionally include additional objects providing impression context.
+"""
 
 from decimal import Decimal
 
@@ -7,7 +12,8 @@ from .base import Object, Array, Field
 
 
 class Publisher(Object):
-    u"""
+    u"""This object describes the publisher of a site or app, depending on which object it is embedded in.
+
     The publisher object itself and all of its parameters are optional, so default values are not provided.
     If an optional parameter is not specified, it should be considered unknown.
     """
@@ -19,7 +25,8 @@ class Publisher(Object):
 
 
 class Producer(Object):
-    u"""
+    u"""This object describes the content of a site or app, depending on which object its parent is embedded in.
+
     The producer is useful when content where the ad is shown is syndicated,
     and may appear on a completely different publisher.
     The producer object itself and all of its parameters are optional, so default values are not provided.
@@ -34,7 +41,8 @@ class Producer(Object):
 
 
 class Geo(Object):
-    u"""
+    u"""Depending on the parent object, this object describes the current geographic location of the device, or it may describe the home geo of the user.
+
     The geo object itself and all of its parameters are optional, so default values are not provided.
     If an optional parameter is not specified, it should be considered unknown.
     Note that the Geo Object may appear in one or both the Device Object and the User Object.
@@ -60,7 +68,8 @@ class Geo(Object):
 
 
 class Segment(Object):
-    u"""
+    u"""The segment object is a child of the data object, and describes data segments applicable to the user for the given data provider.
+
     The data and segment objects together allow data about the user to be passed to bidders in the bid request.
     Segment objects convey specific units of information from the provider identified in the parent data object.
     The segment object itself and all of its parameters are optional, so default values are not provided;
@@ -73,7 +82,9 @@ class Segment(Object):
 
 
 class Data(Object):
-    u"""
+    u"""The data object is a child of the user object and describes a data source.
+    Once segment objects are embedded, data about the user may be passed to bidders.
+
     The data and segment objects together allow data about the user to be passed to bidders in the bid request.
     This data may be from multiple sources (e.g., the exchange itself, third party providers)
     as specified by the data object ID field. A bid request can mix data objects from multiple providers.
@@ -87,7 +98,8 @@ class Data(Object):
 
 
 class User(Object):
-    u"""
+    u"""This object describes the user, and may include unique identifiers for the user.
+
     The “user” object contains information known or derived about the human user of the device.
     Note that the user ID is an exchange artifact (refer to the “device” object for hardware or platform derived IDs)
     and may be subject to rotation policies.
@@ -108,7 +120,8 @@ class User(Object):
 
 
 class Device(Object):
-    u"""
+    u"""This object describes the device the ad impression will be delivered to and its capabilities.
+
     The “device” object provides information pertaining to the device including
     its hardware, platform, location, and carrier.
     This device can refer to a mobile handset, a desktop computer, set top box or other digital device.
@@ -143,7 +156,8 @@ class Device(Object):
 
 
 class Content(Object):
-    u"""
+    u"""This object describes the content of a site or app, depending on which object it is embedded in.
+
     The content object itself and all of its parameters are optional, so default values are not provided.
     If an optional parameter is not specified, it should be considered unknown.
     This object describes the content in which the impression will appear (may be syndicated or non-syndicated content).
@@ -173,7 +187,8 @@ class Content(Object):
 
 
 class Site(Object):
-    u"""
+    u"""Either a site or app object may be included – not both. Neither is required.
+
     A site object should be included if the ad supported content is part of a website (as opposed to an application).
     A bid request must not contain both a site object and an app object.
     The site object itself and all of its parameters are optional, so default values are not provided.
@@ -197,7 +212,8 @@ class Site(Object):
 
 
 class App(Object):
-    u"""
+    u"""Either a site or app object may be included – not both. Neither is required.
+
     An “app” object should be included if the ad supported content is part of a mobile
     application (as opposed to a mobile website).
     A bid request must not contain both an “app” object and a “site” object.
@@ -222,7 +238,8 @@ class App(Object):
 
 
 class Banner(Object):
-    u"""
+    u"""A banner object typically describes an ad opportunity for banner, rich media or in-banner video inventory.
+
     The “banner” object must be included directly in the impression object
     if the impression offered for auction is display or rich media,
     or it may be optionally embedded in the video object to describe
@@ -253,7 +270,8 @@ class Banner(Object):
 
 
 class Video(Object):
-    u"""
+    u"""A video object typically describes an ad opportunity for in-stream video inventory.
+
     The “video” object must be included directly in the impression object if the impression offered
     for auction is an in-stream video ad opportunity.
     Note that for the video object, many of the fields are non-essential for a minimally viable exchange interfaces.
@@ -284,7 +302,8 @@ class Video(Object):
 
 
 class Impression(Object):
-    u"""
+    u"""At least one impression object is required in a bid request object.
+
     The “imp” object describes the ad position or impression being auctioned.
     A single bid request can include multiple “imp” objects,
     a use case for which might be an exchange that supports selling all ad positions on a given page as a bundle.
@@ -304,7 +323,8 @@ class Impression(Object):
 
 
 class BidRequest(Object):
-    u"""
+    u"""Top-level bid request object.
+
     The top-level bid request object contains a globally unique bid request or auction ID.
     This “id” attribute is required as is at least one “imp” (i.e., impression) object.
     Other attributes are optional since an exchange may establish default values.
